#! /bin/bash

# Test: insert empty strings from MapInfo table into PostGIS
#	try with PG_USE_COPY = YES | NO
#
dbname=test
dbschema=loader
dbuser=test
dbpassword=test

psql -f create_test_schema.sql $dbname $dbuser

config="--config PG_USE_COPY YES --config PG_LIST_ALL_TABLES YES"
mode="-append -update"

rm -f error.log

### PostgreSQL driver

# Geographic table, first column int: OK
ogr2ogr $config $mode -a_srs EPSG:3003 -f 'PostgreSQL' \
	"PG:dbname=$dbname user=$dbuser password=$dbpassword active_schema=$dbschema" \
	"data/PlineTest.TAB" \
	-nlt LINESTRING 2> error.log


# Geographic table, first column char(): OK
ogr2ogr $config $mode -a_srs EPSG:3003 -f 'PostgreSQL' \
	"PG:dbname=$dbname user=$dbuser password=$dbpassword active_schema=$dbschema" \
	"data/PlineFirstTest.TAB" \
	-nlt LINESTRING 2>> error.log


# Non geom table, first column int: error
ogr2ogr $config $mode -f 'PostgreSQL' \
	"PG:dbname=$dbname user=$dbuser password=$dbpassword active_schema=$dbschema" \
	"data/NoGeomTest.TAB" \
	-nlt NONE  2>> error.log

# Non geom table, first column char(): error
ogr2ogr $config $mode -f 'PostgreSQL' \
	"PG:dbname=$dbname user=$dbuser password=$dbpassword active_schema=$dbschema" \
	"data/NoGeomFirstTest.TAB" \
	-nlt NONE  2>> error.log


### PGDump driver

# Geographic table, first column int
# 	gives a Segmentation Fault with PG_USE_COPY=NO
ogr2ogr $config $mode -f 'PgDump' out/PlineTest.sql \
	"data/PlineTest.TAB" \
	-nlt NONE -lco LAUNDER=NO -lco CREATE_TABLE=OFF -lco SCHEMA=loader -lco CREATE_SCHEMA=OFF 2>> error.log

# Geographic table, first column char()
# 	gives a Segmentation Fault with PG_USE_COPY=NO
#	produces wrong SQL (no trailing \t) with PG_USE_COPY=YES
ogr2ogr $config $mode -f 'PgDump' out/PlineFirstTest.sql \
	"data/PlineFirstTest.TAB" \
	-nlt NONE -lco LAUNDER=NO -lco CREATE_TABLE=OFF -lco SCHEMA=loader -lco CREATE_SCHEMA=OFF 2>> error.log


# Non geom table, first column int - OK
ogr2ogr $config $mode -f 'PgDump' out/NoGeomTest.sql \
	"data/NoGeomTest.TAB" \
	-nlt NONE -lco LAUNDER=NO -lco CREATE_TABLE=OFF -lco SCHEMA=loader -lco CREATE_SCHEMA=OFF 2>> error.log

# Non geom table, first column char()
#	produces wrong SQL (no trailing \t) with PG_USE_COPY=YES
ogr2ogr $config $mode -f 'PgDump' out/NoGeomFirstTest.sql \
	"data/NoGeomFirstTest.TAB" \
	-nlt NONE -lco LAUNDER=NO -lco CREATE_TABLE=OFF -lco SCHEMA=loader -lco CREATE_SCHEMA=OFF 2>> error.log

